@@ -2,10 +2,11 @@ import logging
 from django.core.exceptions import ValidationError
 from django.utils.translation import ugettext_lazy as _
 from django import forms
-from jira import JIRAClient
+from .jira import JIRAClient
 
 log = logging.getLogger(__name__)
 
+
 class JIRAOptionsForm(forms.Form):
     instance_url = forms.CharField(
         label=_("JIRA Instance URL"),
@@ -75,9 +76,9 @@ class JIRAOptionsForm(forms.Form):
         """
         url = self.cleaned_data.get("instance_url")
         if url and url[-1:] == "/":
-          return url[:-1]
+            return url[:-1]
         else:
-          return url
+            return url
 
     def clean(self):
         """
@@ -115,10 +116,11 @@ class JIRAOptionsForm(forms.Form):
 # A list of common builtin custom field types for JIRA for easy reference.
 CUSTOM_FIELD_TYPES = {
     "select": "com.atlassian.jira.plugin.system.customfieldtypes:select",
-    "textarea": "com.atlassian.jira.plugin.system.customfieldtypes:textarea", 
+    "textarea": "com.atlassian.jira.plugin.system.customfieldtypes:textarea",
     "multiuserpicker": "com.atlassian.jira.plugin.system.customfieldtypes:multiuserpicker"
 }
 
+
 class JIRAIssueForm(forms.Form):
 
     project_key = forms.CharField(widget=forms.HiddenInput())
@@ -138,12 +140,16 @@ class JIRAIssueForm(forms.Form):
     )
 
     def __init__(self, *args, **kwargs):
-        ignored_fields = kwargs.pop("ignored_fields")
+        self.ignored_fields = kwargs.pop("ignored_fields")
         initial = kwargs.get("initial")
         jira_client = initial.pop("jira_client")
 
         priorities = jira_client.get_priorities().json
         versions = jira_client.get_versions(initial.get("project_key")).json
+
+        # Returns the metadata the configured JIRA instance requires for
+        # creating issues for a given project. 
+        # https://developer.atlassian.com/static/rest/jira/5.0.html#id200251
         meta = jira_client.get_create_meta(initial.get("project_key")).json
 
         # Early exit, somehow made it here without properly configuring the
@@ -162,7 +168,8 @@ class JIRAIssueForm(forms.Form):
                   jira_client.username]
             return
 
-
+        # Looking up the project meta by exact key, so it's always the first
+        # one.
         project = meta["projects"][0]
         issue_types = project["issuetypes"]
 
@@ -190,13 +197,13 @@ class JIRAIssueForm(forms.Form):
         anti_gravity = {"priority": -150,
                         "fixVersions": -125,
                         "components": -100,
-                        "security": -50 }
+                        "security": -50}
 
         dynamic_fields = self.issue_type.get("fields").keys()
         dynamic_fields.sort(key=lambda f: anti_gravity.get(f) or 0)
         # build up some dynamic fields based on required shit.
         for field in dynamic_fields:
-            if field in self.fields.keys() or field in [x.strip() for x in ignored_fields.split(",")]:
+            if field in self.fields.keys() or field in [x.strip() for x in self.ignored_fields.split(",")]:
                 # don't overwrite the fixed fields for the form.
                 continue
             mb_field = self.build_dynamic_field(self.issue_type["fields"][field])
@@ -212,7 +219,7 @@ class JIRAIssueForm(forms.Form):
         if "fixVersions" in self.fields.keys():
             self.fields["fixVersions"].choices = self.make_choices(versions)
 
-    make_choices = lambda self, x: [(y["id"], y["name"] if y.has_key("name") else y["value"] ) for y in x] if x else []
+    make_choices = lambda self, x: [(y["id"], y["name"] if "name" in y else y["value"]) for y in x] if x else []
 
     def clean_description(self):
         """
@@ -232,7 +239,7 @@ class JIRAIssueForm(forms.Form):
         # protect against mis-configured plugin submitting a form without an
         # issuetype assigned.
         if not very_clean.get("issuetype"):
-          raise ValidationError("Issue Type is required. Check your plugin configuration.")
+            raise ValidationError("Issue Type is required. Check your plugin configuration.")
 
         fs = self.issue_type["fields"]
         for field in fs.keys():
@@ -244,7 +251,7 @@ class JIRAIssueForm(forms.Form):
                 if v:
                     schema = f["schema"]
                     if schema.get("type") == "string" and not schema.get("custom") == CUSTOM_FIELD_TYPES["select"]:
-                      continue # noop
+                        continue  # noop
                     if schema["type"] == "user" or schema.get('item') == "user":
                         v = {"name": v}
                     elif schema.get("custom") == CUSTOM_FIELD_TYPES.get("multiuserpicker"):
@@ -254,9 +261,9 @@ class JIRAIssueForm(forms.Form):
                         v = [{"id": vx} for vx in v]
                     elif schema.get("custom") == CUSTOM_FIELD_TYPES.get("textarea"):
                         v = v
-                    elif schema.get("type") != "string"\
-                      or schema.get("item") != "string"\
-                      or schema.get("custom") == CUSTOM_FIELD_TYPES.get("select"):
+                    elif (schema.get("type") != "string"
+                            or schema.get("item") != "string"
+                            or schema.get("custom") == CUSTOM_FIELD_TYPES.get("select")):
                         v = {"id": v}
                     very_clean[field] = v
                 else:
@@ -277,7 +284,6 @@ class JIRAIssueForm(forms.Form):
 
         return very_clean
 
-
     def build_dynamic_field(self, field_meta):
         """
         Builds a field based on JIRA's meta field information
@@ -292,8 +298,8 @@ class JIRAIssueForm(forms.Form):
         }
 
         # override defaults based on field configuration
-        if schema["type"] in ["securitylevel", "priority"] \
-          or schema.get("custom") == CUSTOM_FIELD_TYPES.get("select"):
+        if (schema["type"] in ["securitylevel", "priority"]
+                or schema.get("custom") == CUSTOM_FIELD_TYPES.get("select")):
             fieldtype = forms.ChoiceField
             fkwargs["choices"] = self.make_choices(field_meta.get('allowedValues'))
             fkwargs["widget"] = forms.Select()
