@@ -1,10 +1,10 @@
 import urllib
 import urlparse
 
+from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.utils.translation import ugettext_lazy as _
-from sentry.conf import settings
 from sentry.models import GroupMeta
 from sentry.plugins.base import Response
 from sentry.plugins.bases.issue import IssuePlugin
@@ -54,6 +54,7 @@ class JIRAPlugin(IssuePlugin):
             'summary': self._get_group_title(request, group, event),
             'description': self._get_group_description(request, group, event),
             'project_key': self.get_option('default_project', group.project),
+            'issuetype': request.POST.get('issuetype'),
             'jira_client': self.get_jira_client(group.project)
         }
 
@@ -98,7 +99,9 @@ class JIRAPlugin(IssuePlugin):
         has_auth_configured = self.has_auth_configured()
         if not (has_auth_configured and self.is_configured(project=group.project, request=request)):
             if self.auth_provider:
-                required_auth_settings = settings.AUTH_PROVIDERS[self.auth_provider]
+                providers = settings.AUTH_PROVIDERS if hasattr(
+                    settings, 'AUTH_PROVIDERS') else settings.SENTRY_AUTH_PROVIDERS
+                required_auth_settings = providers[self.auth_provider]
             else:
                 required_auth_settings = None
 
@@ -132,12 +135,12 @@ class JIRAPlugin(IssuePlugin):
             request.POST or None,
             initial=self.get_initial_form_data(request, group, event),
             ignored_fields=self.get_option("ignored_fields", group.project))
-        ########################################################################
+        #######################################################################
         # to allow the form to be submitted, but ignored so that dynamic fields
         # can change if the issuetype is different
         #
         if request.POST and request.POST.get("changing_issuetype") == "0":
-        ########################################################################
+        #######################################################################
             if form.is_valid():
                 issue_id, error = self.create_issue(
                     group=group,
@@ -147,6 +150,18 @@ class JIRAPlugin(IssuePlugin):
                 if error:
                     form.errors.update(error)
 
+                    # Register field errors which were returned from the JIRA
+                    # API, but were marked as ignored fields in the
+                    # configuration with the global error reporter for the form
+                    ignored_errors = [v for k, v in error.items()
+                                      if k in form.ignored_fields.split(",")]
+                    if len(ignored_errors) > 0:
+                        errs = form.errors['__all__']
+                        errs.append("Validation Error on ignored field, check"
+                                    " your plugin settings.")
+                        errs.extend(ignored_errors)
+                        form.errors['__all__'] = errs
+
             if form.is_valid():
                 GroupMeta.objects.set_value(group, '%s:tid' % prefix, issue_id)
 
